@@ -3,9 +3,11 @@ Main interface for sts service type definitions.
 
 Usage::
 
-    from mypy_boto3.sts.type_defs import AssumedRoleUserTypeDef
+    ```python
+    from mypy_boto3_sts.type_defs import AssumedRoleUserTypeDef
 
     data: AssumedRoleUserTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
